-- name=int_morph_secret
--******************************************************************************************
function public.Init ( pos_z )

  ObjAttach( "int_morph_secret", interface.originhub );
  ObjSet( "int_morph_secret", { pos_z = pos_z } );
  MsgSubscribe( Command_Interface_UpdateTextures, private.WideScreenUpdate );

  private.MOVE_ANIM_TIME      =  0.6;
  private.MOVE_ANIM_POS_X_BEG =   -188;
  private.MOVE_ANIM_POS_X_END =   183;
  private.DIRECTION =  -1;
  private.POS_Y =  266;

  private.WideScreenUpdate();
  --public.SetTaskText( 1 );
  --public.SetTaskCount( 1 );

  ObjMultiSet( {
    { "obj_int_morph_secret_root", { visible = false } },
    { "obj_int_morph_secret",      { pos_x = private.MOVE_ANIM_POS_X_BEG } },
  } );

end;
--******************************************************************************************
function public.Destroy ()

  MsgUnsubscribe( Command_Interface_UpdateTextures, private.WideScreenUpdate );

end;
--******************************************************************************************
function private.WideScreenUpdate ()

  local direction = private.DIRECTION or 0;

  if ( direction ~= 0 and ObjGet( "int_morph_secret" ) ) then

    local offset = 0.5 * ( GetAppWidth() - 1024 );
    local position = -43;

    local posx = position + ( direction * offset );
    ObjSet( "obj_int_morph_secret_root", { pos_x = posx, pos_y = private.POS_Y } );

  end;

end;
--******************************************************************************************
function public.Show ( )

  --private.count_collect2_item = number;
  ObjSet( "obj_int_morph_secret_root", { active = true, visible = true, input = true } ); 
  local task = ng_global.secret.curren_task; 
  public.SetTaskText( task );
  public.SetTaskCount( task );
  private.SetTaskIcon( task );
  private.ShowAnim( "show" );
  int_taskpanel_secret.UpdateAchievpanel();

end;
--******************************************************************************************
function public.Hide ()

  ObjSet( "obj_int_morph_secret_root", { input = false } );  
  private.HideAnim( );

end;
--******************************************************************************************
function public.SetTaskText ( task )

  ObjSet( "txt_int_morph_secret_task", {
    text = StringGet( "str_task_secret_"..task );
  } );

end;
--******************************************************************************************
function public.SetTaskCount ( task )

  local all_count = private.GetAllCount( task );
  local curr_count = private.GetCount( task );


  ObjSet( "txt_int_morph_secret_counter", {
    text = curr_count.." / "..all_count,
  } );

end;
--******************************************************************************************
function private.SetTaskIcon ( task )

  ObjSet( "spr_int_morph_secret_icon", {
    res = "assets/interface/resources/morph_secret/"..task,
  } );
  ObjSet( "spr_int_morph_secret_icon_off", {
    res = "assets/interface/resources/morph_secret/"..task.."_off",
  } );

end;
--******************************************************************************************
function public.UpdateTaskIcon ( task )

  ObjMultiSet( {
    { "spr_int_morph_secret_icon",      { alp = 1 } },
    { "spr_int_morph_secret_icon_off",  { alp = 0 } },
  } );

  if ( private.GetCountOnLocation( task ) and task ~= "skull" ) then

    ObjMultiSet( {
      { "spr_int_morph_secret_icon",      { alp = 0 } },
      { "spr_int_morph_secret_icon_off",  { alp = 1 } },
    } );

  end;

end;
--******************************************************************************************
function private.GetAllCount ( task )

  local count = 0;

  if ( task ~= "ghost" ) then

    for key, value in pairs( ng_global.secret.location ) do

      count = count + #ng_global.secret.location[ key ][ task ];

    end;

  else

    count = 1;

  end;

  return count;

end;
--******************************************************************************************
function private.GetCount ( task )

  local count = 0;  
  local bool_break = false;

  for key, value in pairs( ng_global.secret.location ) do

    for i = 1, #ng_global.secret.location[ key ][ task ] do

      if ( task == "ghost" ) then

        count = 1;
        if ( not ng_global.secret.location[ key ][ task ][ i ] ) then

          bool_break = true;
          count = 0;
          break;

        end;

      else

        if ( ng_global.secret.location[ key ][ task ][ i ] ) then

          count = count + 1;

        end;

      end;

      if ( bool_break ) then  
        break;
      end;

    end;

    if ( bool_break ) then  
      break;
    end;

  end;
  
  return count;

end;
--******************************************************************************************
function private.GetCountOnLocation ( task )

  local count = 0;  
  local room = GetCurrentRoom();

  for i = 1, #ng_global.secret.location[ room ][ task ] do

    if ( ng_global.secret.location[ room ][ task ][ i ] ) then

      count = count + 1;

    end;

  end;
  
  return count == #ng_global.secret.location[ room ][ task ];

end;
--******************************************************************************************
function private.ShowAnim ( )

  local obj       = "obj_int_morph_secret";
  local tme       = private.MOVE_ANIM_TIME;
  local current_posx = ObjGet( obj ).pos_x; 
  local distance = math.abs( private.MOVE_ANIM_POS_X_BEG - current_posx );

  ObjSet( "obj_int_morph_secret_root", { visible = true } );
  if ( distance ~= 0 ) then

    local overtime = distance * ( tme / ( private.MOVE_ANIM_POS_X_END - private.MOVE_ANIM_POS_X_BEG ) );
    ObjAnimate( obj, "pos_x", 0, 0, "",
    {
      0.0,          2, current_posx,
      overtime,     2, private.MOVE_ANIM_POS_X_BEG,
      overtime+tme, 2, private.MOVE_ANIM_POS_X_END
    } );
  
  else
  
    ObjAnimate( obj, "pos_x", 0, 0, "",
    {
      0.0, 2, private.MOVE_ANIM_POS_X_BEG,
      tme, 2, private.MOVE_ANIM_POS_X_END
    } );

  end;

end;
--******************************************************************************************
function private.HideAnim ( )

  local obj           = "obj_int_morph_secret";
  --local func_end      = function () private.EventAnimEnd( event_id ); end;
  local tme           = private.MOVE_ANIM_TIME;  
  local current_posx  = private.MOVE_ANIM_POS_X_END;

  ObjStopAnimate( obj, "pos_x" ); 
  current_posx = ObjGet( obj ).pos_x;  
  
  ObjAnimate( obj, "pos_x", 0, 0, "",
  {
    0.0, 1, current_posx,
    tme, 1, private.MOVE_ANIM_POS_X_BEG
  } );

end;
--******************************************************************************************


























