-- name=rm_stairflight
--*********************************************************************************************************************
function public.Init ()
  --------------------------------------------------------------------------------------------
  private.room_objname = "rm_stairflight";
  --------------------------------------------------------------------------------------------
  ObjAttach( "zz_stairs",        "room_hub" );
  ObjAttach( "zz_piledcorridor", "room_hub" );
  ObjAttach( "zz_wall_lvl2",     "room_hub" );
  ObjAttach( "zz_boxes_lvl2",    "room_hub" );

  private.Init_Subroom();
  private.InitAnimations();
  
  ObjMultiSet({ 
    { "spr_stairs_gardenglove",             { event_mdown = private.get_gardenglove      }},
    { "obj_stairs_clk_amuletleaf",          { event_mdown = private.clk_amuletleaf       }},
    { "obj_stairs_use_amuletleaf",          { event_mdown = private.AnimUseAmuletleaf    }},

    { "spr_piledcorridor_skull4",           { event_mdown = private.get_skull4           }},
    { "spr_piledcorridor_wrench",           { event_mdown = private.get_wrench           }},
    { "obj_piledcorridor_clk_things",       { event_mdown = private.clk_things           }},
    { "obj_piledcorridor_use_file",         { event_mdown = private.AnimUseFile          }},

    { "spr_wall_lvl2_button",               { event_mdown = private.get_button_lvl2      }},
    { "spr_wall_lvl2_pattern",              { event_mdown = private.get_pattern          }},
    { "spr_wall_lvl2_skull5",               { event_mdown = private.get_skull5           }},
    { "obj_wall_lvl2_clk_cleaningsprayer",  { event_mdown = private.clk_cleaningsprayer  }},
    { "obj_wall_lvl2_clk_portrait",         { event_mdown = private.clk_portrait         }},
    { "obj_wall_lvl2_use_wrench",           { event_mdown = private.AnimUseWrench        }},

    { "spr_boxes_lvl2_decoration",          { event_mdown = private.get_decoration       }},
    { "obj_boxes_lvl2_clk_rubbedkey",       { event_mdown = private.clk_rubbedkey        }},
    { "obj_boxes_lvl2_use_rubbedkey",       { event_mdown = private.AnimUseRubbedkey     }},
    
    { "obj_stairflight_use_flashlight",     { event_mdown = private.AnimUseFlashlight    }},

    { "spr_stairflight_collect_morph_item", { event_mdown = function() common_impl.GetMorphItem( "get_collect_morph_item_12" ); end } },
      
    { "spr_stairs_collect2_item_10",        { event_mdown = private.get_collect2_item_10 }}, 
  });

  --------------------------------------------------------------------------------------------
  -- function UpdateGameMode () end;
  --------------------------------------------------------------------------------------------
  local update_game_mode_stairflight = function ()
  
    table_multiset = {};
    local res_sparkle_area = "assets/levels/common/fx/sparkle_effect";  
    if ( ng_global.gamemode == 3 and not ng_global.gamemode_custom[ "sparkle_area" ] ) then    
      res_sparkle_area = "";
    end;
    local visible_sparkle_ho = "assets/levels/common/fx/ho_effect";  
    if ( ng_global.gamemode == 3 and not ng_global.gamemode_custom[ "sparkle_ho" ] ) then    
      visible_sparkle_ho = "";
    end;
    local gates = 
    {
      "gho_stairflight_withflashlight",
      "gzz_stairflight_stairs",
      "gzz_stairflight_piledcorridor",
      "gzz_stairflight_wall_lvl2",
      "gzz_stairflight_boxes_lvl2",
    };
    for i = 1, #gates do
      local name = gates[ i ];
      if ( common.GetObjectPrefix( name ) == "gho" ) then
      table.insert( table_multiset, { name, { res = visible_sparkle_ho } } );
      elseif ( common.GetObjectPrefix( name ) ~= "grm" ) then        
      table.insert( table_multiset, { name, { res = res_sparkle_area } } );
      end;
    end;

    local mas_parent_gfx = 
    {
      private.room_objname,
      "zz_stairs",
      "zz_piledcorridor",
      "zz_wall_lvl2",
      "zz_boxes_lvl2",
    };
    common_impl.TurnChildGfx( mas_parent_gfx, private.room_objname, res_sparkle_area );

    if ( #table_multiset > 0 ) then
      ObjMultiSet( table_multiset );
    end;

  end;
  cmn.AddSubscriber( "update_game_mode_stairflight", update_game_mode_stairflight, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function UpdatePerfMode () end;
  --------------------------------------------------------------------------------------------
  local update_performance_mode_stairflight = function ()

    local effects_table = 
    {
      "obj_stairflight_anim" 
    }

    local active = true;
    if ( GetPerformanceMode() == 1 ) then
      active = false;
    end;

    for i = 1, #effects_table do
      ObjSet( effects_table[ i ], { active = active } )
    end;

  end;
  cmn.AddSubscriber( "update_performance_mode_stairflight", update_performance_mode_stairflight, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function opn_stairflight () end;
  --------------------------------------------------------------------------------------------
  local opn_stairflight_map = function ()

    common_impl.VisitMapRoom( "stairflight" );

  end;
  cmn.AddSubscriber( "opn_stairflight", opn_stairflight_map );
  --------------------------------------------------------------------------------------------
  -- function get_collect_morph_item_12 () end;
  --------------------------------------------------------------------------------------------
  local get_collect_morph_item_12 = function ()
  
    ObjDelete( "obj_stairflight_morph" );
  
  end;    
  cmn.AddSubscriber( "get_collect_morph_item_12", get_collect_morph_item_12, private.room_objname ); 
  --------------------------------------------------------------------------------------------
  -- function get_gardenglove () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "get_gardenglove" ] = {
    type = "get",
    get_obj = "spr_stairs_gardenglove",
    room = private.room_objname,
    zz = "zz_stairs",
    zz_gate = "gzz_stairflight_stairs"
  };
  
  local get_gardenglove_inv = function ()
  
    interface.InventoryItemAdd( "inv_gardenglove", "spr_stairs_gardenglove" );
  
  end;
  
  local get_gardenglove_closezz = function ()
  
    ObjDelete( "gfx_stairs_gardenglove" );
    
    if ( cmn.IsGetCollect2( "get_collect2_item_10" ) ) then
      ObjDelete( "gzz_stairflight_stairs" );
    end; 
  
  end;
  
  cmn.AddSubscriber( "get_gardenglove", get_gardenglove_inv );
  cmn.AddSubscriber( "get_gardenglove", get_gardenglove_closezz, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function get_skull4 () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "get_skull4" ] = {
    type = "get",
    get_obj = "spr_piledcorridor_skull4",
    room = private.room_objname,
    zz = "zz_piledcorridor",
    zz_gate = "gzz_stairflight_piledcorridor"
  };
  
  local get_skull4_inv = function ()
  
    local count = 0;
    
    for i = 1, 6 do
      if ( cmn.IsEventDone( "get_skull"..i ) ) then
        count = count + 1;
      end;
    end;

    interface.InventoryItemAdd( "inv_skull", "spr_piledcorridor_skull4", "assets/levels/level2/inv_deploy/inv_scoop_2/inv/inv_skull" );

    if count == 6 then
      ObjSet( "inv_skull", { drag = true } );
    else 
      ObjSet( "inv_skull", { drag = false } );
    end; 
    
    ObjSet( "inv_skull", { res = "assets/levels/level2/inv_deploy/inv_scoop_2/inv/inv_skull"..count } );
    
  end;
  
  local get_skull4_closezz = function ()
  
    ObjDelete( "gfx_piledcorridor_skull4" );
    
    if ( cmn.IsEventDone( "get_wrench" ) ) then
      ObjDelete( "gzz_stairflight_piledcorridor" );
    end;
    
  end;
  
  cmn.AddSubscriber( "get_skull4", get_skull4_inv );
  cmn.AddSubscriber( "get_skull4", get_skull4_closezz, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function get_wrench () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "get_wrench" ] = {
    type = "get",
    get_obj = "spr_piledcorridor_wrench",
    room = private.room_objname,
    zz = "zz_piledcorridor",
    zz_gate = "gzz_stairflight_piledcorridor"
  };
  
  local get_wrench_inv = function ()
  
    interface.InventoryItemAdd( "inv_wrench", "spr_piledcorridor_wrench" );
  
  end;
  
  local get_wrench_closezz = function ()
  
    ObjDelete( "gfx_piledcorridor_wrench" );
    
    if ( cmn.IsEventDone( "get_skull4" ) ) then
      ObjDelete( "gzz_stairflight_piledcorridor" );
    end;
  
  end;
  
  cmn.AddSubscriber( "get_wrench", get_wrench_inv );
  cmn.AddSubscriber( "get_wrench", get_wrench_closezz, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function get_button_lvl2 () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "get_button_lvl2" ] = {
    type = "get",
    get_obj = "spr_wall_lvl2_button",
    room = private.room_objname,
    zz = "zz_wall_lvl2",
    zz_gate = "gzz_stairflight_wall_lvl2"
  };
  
  local get_button_lvl2_inv = function ()
  
    interface.InventoryItemAdd( "inv_button_lvl2", "spr_wall_lvl2_button" );
  
  end;
  
  local get_button_lvl2_closezz = function ()
  
    ObjDelete( "gfx_wall_lvl2_button"                );
    ObjDelete( "spr_stairflight_zz_wall_lvl2_button" );
  
  end;
  
  cmn.AddSubscriber( "get_button_lvl2", get_button_lvl2_inv );
  cmn.AddSubscriber( "get_button_lvl2", get_button_lvl2_closezz, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function get_pattern () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "get_pattern" ] = {
    type = "get",
    get_obj = "spr_wall_lvl2_pattern",
    room = private.room_objname,
    zz = "zz_wall_lvl2",
    zz_gate = "gzz_stairflight_wall_lvl2"
  };
  
  local get_pattern_inv = function ()
  
    interface.InventoryItemAdd( "inv_pattern", "spr_wall_lvl2_pattern" );
  
  end;
  
  local get_pattern_closezz = function ()
  
    ObjDelete( "gfx_wall_lvl2_pattern"               );
    ObjDelete( "spr_stairflight_zz_wall_lvl2_amulet" );  
  
    if ( cmn.IsEventDone( "get_skull5" ) ) then
      ObjDelete( "gzz_stairflight_wall_lvl2" );
    end;
    
  end;
  
  cmn.AddSubscriber( "get_pattern", get_pattern_inv );
  cmn.AddSubscriber( "get_pattern", get_pattern_closezz, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function get_skull5 () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "get_skull5" ] = {
    type = "get",
    get_obj = "spr_wall_lvl2_skull5",
    room = private.room_objname,
    zz = "zz_wall_lvl2",
    zz_gate = "gzz_stairflight_wall_lvl2"
  };
  
  local get_skull5_inv = function ()
  
    local count = 0;
    
    for i = 1, 6 do
      if ( cmn.IsEventDone( "get_skull"..i ) ) then 
        count = count + 1;
      end;
    end;

    interface.InventoryItemAdd( "inv_skull", "spr_wall_lvl2_skull5", "assets/levels/level2/inv_deploy/inv_scoop_2/inv/inv_skull" );

    if count == 6 then
      ObjSet( "inv_skull", { drag = true } );
    else 
      ObjSet( "inv_skull", { drag = false } );
    end; 
    
    ObjSet( "inv_skull", { res = "assets/levels/level2/inv_deploy/inv_scoop_2/inv/inv_skull"..count } );
    
  end;
  
  local get_skull5_closezz = function ()
  
    ObjDelete( "gfx_wall_lvl2_skull5" );
    
    if ( cmn.IsEventDone( "get_pattern" ) ) then
      ObjDelete( "gzz_stairflight_wall_lvl2" );
    end;
  
  end;
  
  cmn.AddSubscriber( "get_skull5", get_skull5_inv );
  cmn.AddSubscriber( "get_skull5", get_skull5_closezz, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function get_decoration () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "get_decoration" ] = {
    type = "get",
    get_obj = "spr_boxes_lvl2_decoration",
    room = private.room_objname,
    zz = "zz_boxes_lvl2",
    zz_gate = "gzz_stairflight_boxes_lvl2"
  };
  
  local get_decoration_inv = function ()
  
    interface.InventoryItemAdd( "inv_decoration", "spr_boxes_lvl2_decoration" );
    ObjSet( "inv_decoration", { drag = false } );
  
  end;
  
  local get_decoration_closezz = function ()
  
    ObjDelete( "gfx_boxes_lvl2_decoration" );
    ObjDelete( "gzz_stairflight_boxes_lvl2" );
  
  end;
  
  cmn.AddSubscriber( "get_decoration", get_decoration_inv );
  cmn.AddSubscriber( "get_decoration", get_decoration_closezz, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function get_collect2_item_10 () end;
  --------------------------------------------------------------------------------------------
  local get_collect2_item_10 = function ()
  
    ObjDelete( "obj_stairs_collect2_item_10" ); 
  
    if ( cmn.IsEventDone( "get_gardenglove" ) ) then
      ObjDelete( "gzz_stairflight_stairs" );
    end;  
    
  end;    
  cmn.AddSubscriber( "get_collect2_item_10", get_collect2_item_10, private.room_objname );  
  --------------------------------------------------------------------------------------------
  -- function use_amuletleaf () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "use_amuletleaf" ] = {
    type = "use",
    inv_obj = "inv_amuletleaf",
    use_place = "obj_stairs_use_amuletleaf",
    room = private.room_objname,
    zz = "zz_stairs",
    zz_gate = "gzz_stairflight_stairs"
  };
  local use_amuletleaf_inv = function ()
  
    interface.InventoryItemRemove( "inv_amuletleaf" );
  
  end;
  local use_amuletleaf_beg = function ()
  
    ObjDelete( "obj_stairs_use_amuletleaf" );
  
  end;
  local use_amuletleaf_end = function ()
  
    ObjMultiSet( { 
      { "spr_stairs_gardenglove",         {  input = true } },
      { "gfx_stairs_gardenglove",         { active = true } },
      { "spr_stairs_leaf",                {    alp = 1    } },
      { "spr_stairflight_zz_stairs_leaf", {    alp = 1    } },
    } );
    ObjDelete( "spr_stairs_cach_top" );  

  end;
  --------------------------------------------------------------------------------------------
  cmn.AddSubscriber( "use_amuletleaf",     use_amuletleaf_beg, private.room_objname );
  cmn.AddSubscriber( "use_amuletleaf",     use_amuletleaf_inv                       );
  cmn.AddSubscriber( "use_amuletleaf",     use_amuletleaf_end, private.room_objname );
  cmn.AddSubscriber( "use_amuletleaf_inv", use_amuletleaf_inv, private.room_objname );
  cmn.AddSubscriber( "use_amuletleaf_beg", use_amuletleaf_beg, private.room_objname );
  cmn.AddSubscriber( "use_amuletleaf_end", use_amuletleaf_end, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function use_file () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "use_file" ] = {
    type = "use",
    inv_obj = "inv_file",
    use_place = "obj_piledcorridor_use_file",
    room = private.room_objname,
    zz = "zz_piledcorridor",
    zz_gate = "gzz_stairflight_piledcorridor"
  };
  local use_file_inv = function ()
  
    interface.InventoryItemRemove( "inv_file" );
  
  end;
  local use_file_beg = function ()
  
    ObjDelete( "obj_piledcorridor_use_file" );
  
  end;
  local use_file_end = function ()
  
    ObjMultiSet( { 
      { "obj_piledcorridor_clk_things",               { active = true, visible = true, input = true } },
      { "anm_piledcorridor_open_door",                {    alp = 1,      frame = 500                } },
      { "spr_stairflight_zz_piledcorridor_open_door", {    alp = 1                                  } },
    } );
    ObjDelete( "anm_piledcorridor_door_nag"                  );
    ObjDelete( "spr_stairflight_zz_piledcorridor_close_door" );

  end;
  --------------------------------------------------------------------------------------------
  cmn.AddSubscriber( "use_file", use_file_beg, private.room_objname );
  cmn.AddSubscriber( "use_file", use_file_inv );
  cmn.AddSubscriber( "use_file", use_file_end, private.room_objname );
  cmn.AddSubscriber( "use_file_inv", use_file_inv, private.room_objname );
  cmn.AddSubscriber( "use_file_beg", use_file_beg, private.room_objname );
  cmn.AddSubscriber( "use_file_end", use_file_end, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function use_cleaningsprayer () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "use_cleaningsprayer" ] = {
    type = "use",
    inv_obj = "inv_cleaningsprayer",
    use_place = "obj_wall_lvl2_use_cleaningsprayer",
    room = private.room_objname,
    zz = "zz_wall_lvl2",
    zz_gate = "gzz_stairflight_wall_lvl2"
  };
  local use_cleaningsprayer_inv = function ()
  
    interface.InventoryItemRemove( "inv_cleaningsprayer" );
  
  end;
  local use_cleaningsprayer_beg = function ()
  
    ObjDelete( "obj_wall_lvl2_use_cleaningsprayer" );
  
  end;
  local use_cleaningsprayer_end = function ()
  
    ObjMultiSet( { 
      { "obj_wall_lvl2_clk_cleaningsprayer", { input = true, active = true, visible = true } },
      { "spr_wall_lvl2_door2",               {   alp = 1                                   } },
      { "spr_wall_lvl2_door2_handle",        {   alp = 1                                   } },
    } );
    ObjDelete( "anm_wall_lvl2_flask" );
  
  end;
  --------------------------------------------------------------------------------------------
  cmn.AddSubscriber( "use_cleaningsprayer", use_cleaningsprayer_beg, private.room_objname );
  cmn.AddSubscriber( "use_cleaningsprayer", use_cleaningsprayer_inv );
  cmn.AddSubscriber( "use_cleaningsprayer", use_cleaningsprayer_end, private.room_objname );
  cmn.AddSubscriber( "use_cleaningsprayer_inv", use_cleaningsprayer_inv, private.room_objname );
  cmn.AddSubscriber( "use_cleaningsprayer_beg", use_cleaningsprayer_beg, private.room_objname );
  cmn.AddSubscriber( "use_cleaningsprayer_end", use_cleaningsprayer_end, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function use_wrench () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "use_wrench" ] = {
    type = "use",
    inv_obj = "inv_wrench",
    use_place = "obj_wall_lvl2_use_wrench",
    room = private.room_objname,
    zz = "zz_wall_lvl2",
    zz_gate = "gzz_stairflight_wall_lvl2"
  };
  local use_wrench_inv = function ()
  
    interface.InventoryItemRemove( "inv_wrench" );
  
  end;
  local use_wrench_beg = function ()
  
    ObjDelete( "obj_wall_lvl2_use_wrench" );
  
  end;
  local use_wrench_end = function ()
  
    ObjMultiSet( { 
      { "spr_wall_lvl2_button",               { input = true                                } },
      { "gfx_wall_lvl2_button",               {               active = true                 } },
      { "obj_wall_lvl2_use_cleaningsprayer",  { input = true, active = true, visible = true } },
    } );
    ObjDelete( "spr_stairflight_zz_wall_lvl2_door" );
    ObjDelete( "anm_wall_lvl2_door"                );
  
  end;
  --------------------------------------------------------------------------------------------
  cmn.AddSubscriber( "use_wrench", use_wrench_beg, private.room_objname );
  cmn.AddSubscriber( "use_wrench", use_wrench_inv );
  cmn.AddSubscriber( "use_wrench", use_wrench_end, private.room_objname );
  cmn.AddSubscriber( "use_wrench_inv", use_wrench_inv, private.room_objname );
  cmn.AddSubscriber( "use_wrench_beg", use_wrench_beg, private.room_objname );
  cmn.AddSubscriber( "use_wrench_end", use_wrench_end, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function use_rubbedkey () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "use_rubbedkey" ] = {
    type = "use",
    inv_obj = "inv_rubbedkey",
    use_place = "obj_boxes_lvl2_use_rubbedkey",
    room = private.room_objname,
    zz = "zz_boxes_lvl2",
    zz_gate = "gzz_stairflight_boxes_lvl2"
  };
  local use_rubbedkey_inv = function ()
  
    interface.InventoryItemRemove( "inv_rubbedkey" );
  
  end;
  local use_rubbedkey_beg = function ()
  
    ObjDelete( "obj_boxes_lvl2_use_rubbedkey" );
  
  end;
  local use_rubbedkey_end = function ()
  
    ObjMultiSet( { 
      { "spr_boxes_lvl2_key",           {   alp = 1                                   } },
      { "obj_boxes_lvl2_clk_rubbedkey", { input = true, active = true, visible = true } },
    } );

  end;
  --------------------------------------------------------------------------------------------
  cmn.AddSubscriber( "use_rubbedkey", use_rubbedkey_beg, private.room_objname );
  cmn.AddSubscriber( "use_rubbedkey", use_rubbedkey_inv );
  cmn.AddSubscriber( "use_rubbedkey", use_rubbedkey_end, private.room_objname );
  cmn.AddSubscriber( "use_rubbedkey_inv", use_rubbedkey_inv, private.room_objname );
  cmn.AddSubscriber( "use_rubbedkey_beg", use_rubbedkey_beg, private.room_objname );
  cmn.AddSubscriber( "use_rubbedkey_end", use_rubbedkey_end, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function use_flashlight_lvl2_2 () end;
  --------------------------------------------------------------------------------------------
  common_impl.hint[ "use_flashlight_lvl2_2" ] = {
    type = "use",
    inv_obj = "inv_flashlight_lvl2",
    use_place = "obj_stairflight_use_flashlight",
    room = private.room_objname
  };
  local use_flashlight_lvl2_2_inv = function ()
  
    interface.InventoryItemRemove( "inv_flashlight_lvl2" );
  
  end;
  local use_flashlight_lvl2_2_beg = function ()
  
    ObjDelete( "obj_stairflight_use_flashlight" );
  
  end;
  local use_flashlight_lvl2_2_end = function ()
  
    ObjMultiSet( { 
      { "gho_stairflight_withflashlight",  { visible = true, input = true } },
    } );
    ObjDelete( "anm_stairflight_flashlight" );
    
  end;
  --------------------------------------------------------------------------------------------
  cmn.AddSubscriber( "use_flashlight_lvl2_2", use_flashlight_lvl2_2_beg, private.room_objname );
  cmn.AddSubscriber( "use_flashlight_lvl2_2", use_flashlight_lvl2_2_inv );
  cmn.AddSubscriber( "use_flashlight_lvl2_2", use_flashlight_lvl2_2_end, private.room_objname );
  cmn.AddSubscriber( "use_flashlight_lvl2_2_inv", use_flashlight_lvl2_2_inv, private.room_objname );
  cmn.AddSubscriber( "use_flashlight_lvl2_2_beg", use_flashlight_lvl2_2_beg, private.room_objname );
  cmn.AddSubscriber( "use_flashlight_lvl2_2_end", use_flashlight_lvl2_2_end, private.room_objname );
  --------------------------------------------------------------------------------------------
  -- function clk_amuletleaf () end; 
  --------------------------------------------------------------------------------------------
    common_impl.hint[ "clk_amuletleaf" ] = {
      type = "click",
      use_place = "obj_stairs_clk_amuletleaf",
      room = private.room_objname,
      zz = "zz_stairs",
      zz_gate = "gzz_stairflight_stairs"
    };
    local clk_amuletleaf_beg = function ()

      ObjDelete( "obj_stairs_clk_amuletleaf" );
    
    end;
    local clk_amuletleaf_end = function ()

      ObjMultiSet( { 
        { "spr_stairs_carpet_open",            {   alp = 1                                   } },
        { "obj_stairs_use_amuletleaf",         { input = true, visible = true, active = true } },
        { "spr_stairflight_zz_stairs_patch_1", {   alp = 1                                   } },
      } );
      ObjDelete( "spr_stairs_carpet" )
      
    end;
    --------------------------------------------------------------------------------------------
    cmn.AddSubscriber( "clk_amuletleaf",     clk_amuletleaf_beg );
    cmn.AddSubscriber( "clk_amuletleaf",     clk_amuletleaf_end );
    cmn.AddSubscriber( "clk_amuletleaf_beg", clk_amuletleaf_beg );
    cmn.AddSubscriber( "clk_amuletleaf_end", clk_amuletleaf_end );
  --------------------------------------------------------------------------------------------
  -- function clk_things () end; 
  --------------------------------------------------------------------------------------------
    common_impl.hint[ "clk_things" ] = {
      type = "click",
      use_place = "obj_piledcorridor_clk_things",
      room = private.room_objname,
      zz = "zz_piledcorridor",
      zz_gate = "gzz_stairflight_piledcorridor"
    };
    local clk_things_beg = function ()

      ObjDelete( "obj_piledcorridor_clk_things" );
    
    end;
    local clk_things_end = function ()

      ObjMultiSet( { 
        { "spr_piledcorridor_skull4", {  input = true } },
        { "gfx_piledcorridor_skull4", { active = true } },
        { "spr_piledcorridor_wrench", {  input = true } },
        { "gfx_piledcorridor_wrench", { active = true } },

        { "spr_piledcorridor_papper", { pos_x = -25, pos_y = 32  } },
        { "spr_piledcorridor_stucco", { pos_x = 151, pos_y = 272 } },
        { "spr_piledcorridor_wood",   { pos_x = 217, pos_y = 159 } },
        { "spr_piledcorridor_chear",  { pos_x = 246, pos_y = 79  } },
      } );
      
    end;
    --------------------------------------------------------------------------------------------
    cmn.AddSubscriber( "clk_things",     clk_things_beg );
    cmn.AddSubscriber( "clk_things",     clk_things_end );
    cmn.AddSubscriber( "clk_things_beg", clk_things_beg );
    cmn.AddSubscriber( "clk_things_end", clk_things_end );
  --------------------------------------------------------------------------------------------
  -- function clk_portrait () end; 
  --------------------------------------------------------------------------------------------
    common_impl.hint[ "clk_portrait" ] = {
      type = "click",
      use_place = "obj_wall_lvl2_clk_portrait",
      room = private.room_objname,
      zz = "zz_wall_lvl2",
      zz_gate = "gzz_stairflight_wall_lvl2"
    };
    local clk_portrait_beg = function ()

      ObjDelete( "obj_wall_lvl2_clk_portrait" );
    
    end;
    local clk_portrait_end = function ()

      ObjMultiSet( { 
        { "obj_wall_lvl2_use_wrench",           { input = true, visible = true, active = true } },
        { "spr_stairflight_zz_wall_lvl2_layer", {   alp = 1                                   } },
      } );
      ObjDelete( "anm_wall_lvl2_portret" )
      
    end;
    --------------------------------------------------------------------------------------------
    cmn.AddSubscriber( "clk_portrait",     clk_portrait_beg );
    cmn.AddSubscriber( "clk_portrait",     clk_portrait_end );
    cmn.AddSubscriber( "clk_portrait_beg", clk_portrait_beg );
    cmn.AddSubscriber( "clk_portrait_end", clk_portrait_end );
  --------------------------------------------------------------------------------------------
  -- function clk_cleaningsprayer () end; 
  --------------------------------------------------------------------------------------------
    common_impl.hint[ "clk_cleaningsprayer" ] = {
      type = "click",
      use_place = "obj_wall_lvl2_clk_cleaningsprayer",
      room = private.room_objname,
      zz = "zz_wall_lvl2",
      zz_gate = "gzz_stairflight_wall_lvl2"
    };
    local clk_cleaningsprayer_beg = function ()

      ObjDelete( "obj_wall_lvl2_clk_cleaningsprayer" );
    
    end;
    local clk_cleaningsprayer_end = function ()

      ObjMultiSet( { 
        { "spr_wall_lvl2_pattern", {  input = true } },
        { "gfx_wall_lvl2_pattern", { active = true } },
        { "spr_wall_lvl2_skull5",  {  input = true } },
        { "gfx_wall_lvl2_skull5",  { active = true } },

        { "spr_wall_lvl2_door2",        { pos_x = -129, pos_y = -37 } },
        { "spr_wall_lvl2_door2_handle", { pos_x = -98,  pos_y = -33 } },
      } );
      ObjDelete( "spr_stairflight_zz_wall_lvl2_door_open" );

    end;
    --------------------------------------------------------------------------------------------
    cmn.AddSubscriber( "clk_cleaningsprayer",     clk_cleaningsprayer_beg );
    cmn.AddSubscriber( "clk_cleaningsprayer",     clk_cleaningsprayer_end );
    cmn.AddSubscriber( "clk_cleaningsprayer_beg", clk_cleaningsprayer_beg );
    cmn.AddSubscriber( "clk_cleaningsprayer_end", clk_cleaningsprayer_end );
  --------------------------------------------------------------------------------------------
  -- function clk_rubbedkey () end; 
  --------------------------------------------------------------------------------------------
    common_impl.hint[ "clk_rubbedkey" ] = {
      type = "click",
      use_place = "obj_boxes_lvl2_clk_rubbedkey",
      room = private.room_objname,
      zz = "zz_boxes_lvl2",
      zz_gate = "gzz_stairflight_boxes_lvl2"
    };
    local clk_rubbedkey_beg = function ()

      ObjDelete( "obj_boxes_lvl2_clk_rubbedkey" );
    
    end;
    local clk_rubbedkey_end = function ()

      ObjMultiSet( { 
        { "spr_boxes_lvl2_decoration",          { alp = 1, input = true } },
        { "gfx_boxes_lvl2_decoration",          {         active = true } },
        { "spr_boxes_lvl2_cap_open",            { alp = 1               } },
        { "spr_stairflight_zz_boxes_lvl2_open", { alp = 1               } },
      } );
  
      ObjDelete( "anm_boxes_lvl2_open_cap" );
      ObjDelete( "spr_boxes_lvl2_cap"      );
    
    end;
    --------------------------------------------------------------------------------------------
    cmn.AddSubscriber( "clk_rubbedkey",     clk_rubbedkey_beg );
    cmn.AddSubscriber( "clk_rubbedkey",     clk_rubbedkey_end );
    cmn.AddSubscriber( "clk_rubbedkey_beg", clk_rubbedkey_beg );
    cmn.AddSubscriber( "clk_rubbedkey_end", clk_rubbedkey_end );
  --------------------------------------------------------------------------------------------
  -- function see_stairflight_collaps () end;
  --------------------------------------------------------------------------------------------
    local see_stairflight_collaps = function ()
    
      ObjDelete( "anm_stairflight_collapse" );
      
    end;
    --------------------------------------------------------------------------------------------
    cmn.AddSubscriber( "see_stairflight_collaps", see_stairflight_collaps, private.room_objname ); 
  --------------------------------------------------------------------------------------------
  -- function see_stairflight_face () end;
  --------------------------------------------------------------------------------------------
    local see_stairflight_face = function ()
    
      ObjDelete( "anm_stairflight_face" );
      
    end;
    --------------------------------------------------------------------------------------------
    cmn.AddSubscriber( "see_stairflight_face", see_stairflight_face, private.room_objname ); 
  --------------------------------------------------------------------------------------------
  -- function see_stairflight_bats () end;
  --------------------------------------------------------------------------------------------
    local see_stairflight_bats = function ()
    
      ObjDelete( "anm_stairflight_bats" );
      
    end;
    --------------------------------------------------------------------------------------------
    cmn.AddSubscriber( "see_stairflight_bats", see_stairflight_bats, private.room_objname ); 
    
end;
--*********************************************************************************************************************
function public.Load ()
end;
--*********************************************************************************************************************
function private.Init_Subroom ()
  
  --*******************************************************************************************************************
  --*** function zz_wall_lvl2 () end ****
  --*******************************************************************************************************************
    subroom.Define( "zz_wall_lvl2" );
    ------------------------------------------------- 
    function zz_wall_lvl2.Close ()

      if ( not cmn.IsEventDone( "see_stairflight_collaps" ) ) then
        private.see_stairflight_collaps();
      end;
      
    end;
    
end;
--*********************************************************************************************************************
function public.Open ()

  private.opn_stairflight();

  cmn.CallEventHandler( "update_game_mode_"..common.GetObjectName( private.room_objname ) );  
  cmn.CallEventHandler( "update_performance_mode_"..common.GetObjectName( private.room_objname ) );

end;
--*********************************************************************************************************************
function public.PreOpen ()

  common_impl.EnvPlay( { "level2/env/aud_stairflight_env" }, "", 0.5 );
  common_impl.MorphItemMorphing();
  
  if ( cmn.IsEventDone( "win_withflashlight" ) and not cmn.IsEventDone( "see_stairflight_face" ) ) then
    private.see_stairflight_face();
  end;
  
end;
--*********************************************************************************************************************
function public.Close ()
end;
--*********************************************************************************************************************
function public.PreClose ()

  common_impl.StopAudio( "env", "level2/env/aud_stairflight_env", 0.5 );

end;
--*********************************************************************************************************************
-- function *** PROGRESS USE *** () end;
--*********************************************************************************************************************
--------------------------------------------------------------------------------------------
function public.use_amuletleaf ()

  local item = "inv_amuletleaf";

  if ( cmn.ApplyObj( item, "gzz_stairflight_stairs" ) and cmn.IsEventDone( "clk_amuletleaf" ) ) then

    --interface.ObjDoNotDrop( item );
    cmn.GotoSubRoom( "zz_stairs" );

    return true;

  elseif ( cmn.ApplyObj( item, "obj_stairs_use_amuletleaf" ) and cmn.IsEventDone( "clk_amuletleaf" ) ) then

    cmn.CallEventHandler( "use_amuletleaf_inv" );
    cmn.CallEventHandler( "use_amuletleaf_beg" );

    local func_end = function ()

      local func_end_2 = function ()

        cmn.Lock( false );
        cmn.SetEventDone( "use_amuletleaf" );
        cmn.CallEventHandler( "use_amuletleaf_end" );

      end;

      ObjAnimate( "spr_stairs_cach_top","pos_xy", 0, 0, func_end_2, { 
        0.0, 0, ObjGet( "spr_stairs_cach_top" ).pos_x, ObjGet( "spr_stairs_cach_top" ).pos_y,  
        0.4, 0, -358, 120, 
      } );

    end;

    cmn.Lock( true );
    common_impl.PlayAudio( "sfx", "level2/sfx/aud_use_leaf_amulet2", 0, "", 0 );

    cmn.ItemFly( "spr_stairs_leaf", func_end, -1.5 );

    return true;

  end;
  
  return false;
  
end;
--------------------------------------------------------------------------------------------
function public.use_file ()

  local item = "inv_file";

  if ( cmn.ApplyObj( item, "gzz_stairflight_piledcorridor" ) ) then

    --interface.ObjDoNotDrop( item );
    cmn.GotoSubRoom( "zz_piledcorridor" );

    return true;

  elseif ( cmn.ApplyObj( item, "obj_piledcorridor_use_file" ) ) then

    cmn.CallEventHandler( "use_file_inv" );
    cmn.CallEventHandler( "use_file_beg" );

    local func_end = function ()

      local func_end_2 = function ()

        cmn.Lock( false );
        cmn.SetEventDone( "use_file" );
        cmn.CallEventHandler( "use_file_end" );

      end;

      ObjMultiSet( { 
        { "anm_piledcorridor_door_nag",  { alp = 0 } },
        { "anm_piledcorridor_open_door", { alp = 1 } },
      } );
      AnimPlay( "anm_piledcorridor_open_door", "open_door", func_end_2 );

    end;

    cmn.Lock( true );
    common_impl.PlayAudio( "sfx", "level2/sfx/aud_use_file", 0, "", 0 );

    AnimPlay( "anm_piledcorridor_door_nag", "door_nag", func_end );
  
    return true;

  end;
  
  return false;
  
end;
--------------------------------------------------------------------------------------------
function public.use_cleaningsprayer ()

  local item = "inv_cleaningsprayer";

  if ( cmn.ApplyObj( item, "gzz_stairflight_wall_lvl2" ) and cmn.IsEventDone( "get_button_lvl2" ) ) then

    --interface.ObjDoNotDrop( item );
    cmn.GotoSubRoom( "zz_wall_lvl2" );

    return true;

  elseif ( cmn.ApplyObj( item, "obj_wall_lvl2_use_cleaningsprayer" ) and cmn.IsEventDone( "get_button_lvl2" ) ) then

    cmn.CallEventHandler( "use_cleaningsprayer_inv" );
    cmn.CallEventHandler( "use_cleaningsprayer_beg" );

    local func_end = function ()

      cmn.Lock( false );
      cmn.SetEventDone( "use_cleaningsprayer" );
      cmn.CallEventHandler( "use_cleaningsprayer_end" );

    end;

    cmn.Lock( true );
    common_impl.PlayAudio( "sfx", "level2/sfx/aud_use_cleaningsprayer", 0, "", 0 );

    AnimPlay( "anm_wall_lvl2_flask", "DoAnim", func_end );
  
    return true;

  end;
  
  return false;
  
end;
--------------------------------------------------------------------------------------------
function public.use_wrench ()

  local item = "inv_wrench";

  if ( cmn.ApplyObj( item, "gzz_stairflight_wall_lvl2" ) and cmn.IsEventDone( "clk_portrait" ) ) then

    --interface.ObjDoNotDrop( item );
    cmn.GotoSubRoom( "zz_wall_lvl2" );

    return true;

  elseif ( cmn.ApplyObj( item, "obj_wall_lvl2_use_wrench" ) and cmn.IsEventDone( "clk_portrait" ) ) then

    cmn.CallEventHandler( "use_wrench_inv" );
    cmn.CallEventHandler( "use_wrench_beg" );

    local func_end = function ()

      cmn.Lock( false );
      cmn.SetEventDone( "use_wrench" );
      cmn.CallEventHandler( "use_wrench_end" );

    end;

    cmn.Lock( true );
    common_impl.PlayAudio( "sfx", "level2/sfx/aud_use_wrench", 0, "", 0 );

    AnimPlay( "anm_wall_lvl2_door", "DoAnim", func_end );
  
    return true;

  end;
  
  return false;
  
end;
--------------------------------------------------------------------------------------------
function public.use_rubbedkey ()

  local item = "inv_rubbedkey";

  if ( cmn.ApplyObj( item, "gzz_stairflight_boxes_lvl2" ) ) then

    --interface.ObjDoNotDrop( item );
    cmn.GotoSubRoom( 'zz_boxes_lvl2', 'under_frame' );

    return true;

  elseif ( cmn.ApplyObj( item, "obj_boxes_lvl2_use_rubbedkey" ) ) then

    cmn.CallEventHandler( "use_rubbedkey_inv" );
    cmn.CallEventHandler( "use_rubbedkey_beg" );

    local func_end = function ()

      cmn.Lock( false );
      cmn.SetEventDone( "use_rubbedkey" );
      cmn.CallEventHandler( "use_rubbedkey_end" );

    end;

    cmn.Lock( true );
    common_impl.PlayAudio( "sfx", "level2/sfx/aud_use_smallkey", 0, "", 0 );

    cmn.ItemFly( "spr_boxes_lvl2_key", func_end, 1 );
  
    return true;

  end;
  
  return false;
  
end;
--------------------------------------------------------------------------------------------
function public.use_flashlight_lvl2_2 ()

  local item = "inv_flashlight_lvl2";

  if ( cmn.ApplyObj( item, "obj_stairflight_use_flashlight" ) ) then

    cmn.CallEventHandler( "use_flashlight_lvl2_2_inv" );
    cmn.CallEventHandler( "use_flashlight_lvl2_2_beg" );

    local func_end = function ()

      cmn.Lock( false );
      cmn.SetEventDone( "use_flashlight_lvl2_2" );
      cmn.CallEventHandler( "use_flashlight_lvl2_2_end" );

    end;

    cmn.Lock( true );
    common_impl.PlayAudio( "sfx", "level1/sfx/aud_use_flashlight", 0, "", 0 );

    AnimPlay( "anm_stairflight_flashlight", "flashlight", func_end )
  
    return true;

  end;
  
  return false;
  
end;
--*********************************************************************************************************************
-- function *** PROGRESS GET *** () end;
--*********************************************************************************************************************
--------------------------------------------------------------------------------------------
function private.get_gardenglove ()

  common_impl.PlayAudio( "sfx", "aud_get_inv_sfx", 0, "", 0 );

  cmn.SetEventDone( "get_gardenglove" );
  cmn.CallEventHandler( "get_gardenglove" );
  
  if ( cmn.IsGetCollect2( "get_collect2_item_10" ) ) then
    common.CloseSubRoom();
  end;

end;
--------------------------------------------------------------------------------------------
function private.get_skull4 ()

  common_impl.PlayAudio( "sfx", "aud_get_inv_sfx", 0, "", 0 );

  cmn.SetEventDone( "get_skull4" );
  cmn.CallEventHandler( "get_skull4" );
  
  if ( cmn.IsEventDone( "get_wrench" ) ) then 
    common.CloseSubRoom();
  end;

end;
--------------------------------------------------------------------------------------------
function private.get_wrench ()

  common_impl.PlayAudio( "sfx", "aud_get_inv_sfx", 0, "", 0 );

  cmn.SetEventDone( "get_wrench" );
  cmn.CallEventHandler( "get_wrench" );
  
  if ( cmn.IsEventDone( "get_skull4" ) ) then
    common.CloseSubRoom();
  end;
  
end;
--------------------------------------------------------------------------------------------
function private.get_button_lvl2 ()

  common_impl.PlayAudio( "sfx", "aud_get_inv_sfx", 0, "", 0 );

  cmn.SetEventDone( "get_button_lvl2" );
  cmn.CallEventHandler( "get_button_lvl2" );

  if port.isPortable()==1 then
    iOS_RateMe();
  end;
    
end;
--------------------------------------------------------------------------------------------
function private.get_pattern ()

  common_impl.PlayAudio( "sfx", "aud_get_inv_sfx", 0, "", 0 );

  cmn.SetEventDone( "get_pattern" );
  cmn.CallEventHandler( "get_pattern" );
  
  if ( cmn.IsEventDone( "get_skull5" ) ) then
    common.CloseSubRoom();  
  end;
  
end;
--------------------------------------------------------------------------------------------
function private.get_skull5 ()

  common_impl.PlayAudio( "sfx", "aud_get_inv_sfx", 0, "", 0 );

  cmn.SetEventDone( "get_skull5" );
  cmn.CallEventHandler( "get_skull5" );
  
  if ( cmn.IsEventDone( "get_pattern" ) ) then
    common.CloseSubRoom();
  end;

end;
--------------------------------------------------------------------------------------------
function private.get_decoration ()

  common_impl.PlayAudio( "sfx", "aud_get_inv_sfx", 0, "", 0 );

  cmn.SetEventDone( "get_decoration" );
  cmn.CallEventHandler( "get_decoration" );
  
  common.CloseSubRoom();

end;
--------------------------------------------------------------------------------------------
function private.get_collect2_item_10 ()
  
  local func_end = function ()

    cmn.CallEventHandler( "get_collect2_item_10" ); 

  end;

  common_impl.PlayEffectHO( "spr_stairs_collect2_item_10", func_end );
  common_impl.GetCollect2Done( "get_collect2_item_10" );
  
  if ( cmn.IsEventDone( "get_gardenglove" ) ) then
    common.CloseSubRoom();
  end; 
  
end;

--*********************************************************************************************************************
-- function *** PROGRESS CLK *** () end;
--*********************************************************************************************************************
function private.clk_amuletleaf ()
  
  cmn.CallEventHandler( "clk_amuletleaf_beg" );

  local func_end = function ()

    cmn.Lock( false );
    cmn.SetEventDone( "clk_amuletleaf" );
    cmn.CallEventHandler( "clk_amuletleaf_end" ); 

  end;
  
  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level1/sfx/aud_xx_clk_cloth", 0, "", 0 );

  ObjAnimate( "spr_stairs_carpet_open", "alp", 0, 0, func_end,{ 0.0, 0, 0,   0.3, 0, 1 } );
  ObjAnimate( "spr_stairs_carpet",      "alp", 0, 0, "",      { 0.0, 0, 1,   0.3, 0, 0 } );

end;
--------------------------------------------------------------------------------------------
function private.clk_things ()
  
  cmn.CallEventHandler( "clk_things_beg" );

  local func_end = function ()

    cmn.Lock( false );
    cmn.SetEventDone( "clk_things" );
    cmn.CallEventHandler( "clk_things_end" ); 

  end;
  
  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level2/sfx/aud_clk_debris2", 0, "", 0 );

  ObjAnimate( "spr_piledcorridor_chear","pos_xy", 0, 0, "", { 
    0.0, 0, ObjGet( "spr_piledcorridor_chear" ).pos_x, ObjGet( "spr_piledcorridor_chear" ).pos_y,  
    0.3, 0, 246, 79, 
  } );
  ObjAnimate( "spr_piledcorridor_wood","pos_xy", 0, 0, "", { 
    0.0, 0, ObjGet( "spr_piledcorridor_wood" ).pos_x, ObjGet( "spr_piledcorridor_wood" ).pos_y, 
    0.2, 0, ObjGet( "spr_piledcorridor_wood" ).pos_x, ObjGet( "spr_piledcorridor_wood" ).pos_y,   
    0.5, 0, 217, 159, 
  } );
  ObjAnimate( "spr_piledcorridor_stucco","pos_xy", 0, 0, "", { 
    0.0, 0, ObjGet( "spr_piledcorridor_stucco" ).pos_x, ObjGet( "spr_piledcorridor_stucco" ).pos_y,  
    0.2, 0, ObjGet( "spr_piledcorridor_stucco" ).pos_x, ObjGet( "spr_piledcorridor_stucco" ).pos_y,
    0.5, 0, 151, 272, 
  } );
  ObjAnimate( "spr_piledcorridor_papper","pos_xy", 0, 0, func_end, { 
    0.0, 0, ObjGet( "spr_piledcorridor_papper" ).pos_x, ObjGet( "spr_piledcorridor_papper" ).pos_y,
    0.4, 0, ObjGet( "spr_piledcorridor_papper" ).pos_x, ObjGet( "spr_piledcorridor_papper" ).pos_y,  
    0.7, 0, -25, 32, 
  } );

end;
--------------------------------------------------------------------------------------------
function private.clk_portrait ()
  
  cmn.CallEventHandler( "clk_portrait_beg" );

  local func_end = function ()

    cmn.Lock( false );
    cmn.SetEventDone( "clk_portrait" );
    cmn.CallEventHandler( "clk_portrait_end" ); 

  end;
  
  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level2/sfx/aud_drop_picture", 0, "", 0 );

  AnimPlay( "anm_wall_lvl2_portret", "DoAnim", func_end )

end;
--------------------------------------------------------------------------------------------
function private.clk_cleaningsprayer ()
  
  cmn.CallEventHandler( "clk_cleaningsprayer_beg" );

  local func_end = function ()

    cmn.Lock( false );
    cmn.SetEventDone( "clk_cleaningsprayer" );
    cmn.CallEventHandler( "clk_cleaningsprayer_end" ); 

  end;
  
  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level2/sfx/aud_opn_slide_door", 0, "", 0 );

  ObjAnimate( "spr_wall_lvl2_door2","pos_xy", 0, 0, "", { 
    0.0, 0, ObjGet( "spr_wall_lvl2_door2" ).pos_x, ObjGet( "spr_wall_lvl2_door2" ).pos_y,  
    0.6, 0, -129, -37, 
  } );
  ObjAnimate( "spr_wall_lvl2_door2_handle","pos_xy", 0, 0, func_end, { 
    0.0, 0, ObjGet( "spr_wall_lvl2_door2_handle" ).pos_x, ObjGet( "spr_wall_lvl2_door2_handle" ).pos_y,
    0.6, 0, -98, -33, 
  } );

end;
--------------------------------------------------------------------------------------------
function private.clk_rubbedkey ()
  
  cmn.CallEventHandler( "clk_rubbedkey_beg" );

  local func_end = function ()

    local func_end_2 = function ()

      cmn.Lock( false );
      cmn.SetEventDone( "clk_rubbedkey" );
      cmn.CallEventHandler( "clk_rubbedkey_end" ); 

    end;

    AnimPlay( "anm_boxes_lvl2_open_cap", "DoAnim", func_end_2 )

  end;
  
  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level2/sfx/aud_opn_smallbox", 0, "", 0 );

  ObjAnimate( "anm_boxes_lvl2_open_cap", "alp", 0, 0, func_end,{ 0.0,0,0, 0.3,0,1, 0.6,0,1 } );
  ObjAnimate( "spr_boxes_lvl2_cap",      "alp", 0, 0, "",      { 0.0,0,1, 0.3,0,0, 0.6,0,0 } );

end;
--------------------------------------------------------------------------------------------
--*********************************************************************************************************************
-- function *** PROGRESS WIN *** () end;
--*********************************************************************************************************************
--*********************************************************************************************************************
-- function *** PROGRESS DLG *** () end;
--*********************************************************************************************************************
--*********************************************************************************************************************
-- function *** PROGRESS SEE *** () end;
--*********************************************************************************************************************
function public.SwitchFrase ( dlg_name, count_txt )
end;
--------------------------------------------------------------------------------------------
function private.see_stairflight_collaps ()

  local func_end = function ()
  
    cmn.Lock( false );
    cmn.SetEventDone( "see_stairflight_collaps" );

    common_impl.ShowBbt( 'bbt_stairflight_see_collaps' );
    
  end;
  
  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level1/sfx/aud_sc_destruction", 0, "", 0 );

  AnimPlay( "anm_stairflight_collapse", "collapse", func_end );
  
end;
--------------------------------------------------------------------------------------------
function private.see_stairflight_face ()

  local func_end = function ()
  
    cmn.Lock( false );
    cmn.SetEventDone( "see_stairflight_face" );

    common_impl.ShowBbt( 'bbt_stairflight_see_face' );
    
  end;
  
  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level1/sfx/aud_", 0, "", 0 );

  AnimPlay( "anm_stairflight_face", "face", func_end );
  
end; 
--------------------------------------------------------------------------------------------
function private.see_stairflight_bats ()

  local func_end = function ()
  
    cmn.Lock( false );
    cmn.SetEventDone( "see_stairflight_bats" );

    common_impl.ShowBbt( 'bbt_stairflight_see_bats' );
    
  end;
  
  --cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level1/sfx/aud_", 0, "", 0 );

  AnimPlay( "anm_stairflight_mad_bats", "bats_mad", func_end );  
  
end;
--*********************************************************************************************************************
-- function *** OTHER *** () end;
--*********************************************************************************************************************
function private.opn_stairflight ()

  if not ( cmn.IsEventDone( "opn_stairflight" ) ) then

    cmn.SetEventDone( "opn_stairflight" );
    common_impl.ShowBbt( 'bbt_stairflight_opn_stairflight' );

  end;
  cmn.CallEventHandler( "opn_stairflight" );
  
end;
--*********************************************************************************************************************
-- function *** ANIMATION *** () end;
--*********************************************************************************************************************
function private.InitAnimations ()
end;
--*********************************************************************************************************************
-- function *** FEEDBACK ANIM *** () end;
--*********************************************************************************************************************
--------------------------------------------------------------------------------------------
function private.AnimUseAmuletleaf ()

  common_impl.ShowBbt( 'bbt_stairs_use_amuletleaf' );

  local func_end = function ()
    cmn.Lock( false );
  end;

  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level2/sfx/aud_xx_clk_wood_mid3", 0, "", 0 );
  
  ObjAnimate( "spr_stairs_cach_top", "pos_y", 0, 1, func_end, { 0, 0, 0,   0.2, 3, -2,   0.4, 3, 0 });

end;
--------------------------------------------------------------------------------------------
function private.AnimUseFile ()

  common_impl.ShowBbt( 'bbt_piledcorridor_use_file' );

  local func_end = function ()

    cmn.Lock( false );
    ObjMultiSet( { 
      { "anm_piledcorridor_door_nag", { alp = 1 } },
      { "anm_piledcorridor_door_hh",  { alp = 0 } },
    } );
  
  end;

  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level2/sfx/aud_xx_metal_low2", 0, "", 0 );
  
  ObjMultiSet( { 
    { "anm_piledcorridor_door_nag", { alp = 0 } },
    { "anm_piledcorridor_door_hh",  { alp = 1 } },
  } );
  AnimPlay( "anm_piledcorridor_door_hh", "door_hh", func_end );

end;
--------------------------------------------------------------------------------------------
function private.AnimUseRubbedkey ()

  common_impl.ShowBbt( 'bbt_boxes_lvl2_use_rubbedkey' );

  local func_end = function ()
    cmn.Lock( false );
  end;

  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level2/sfx/aud_xx_clk_box", 0, "", 0 );
  
  ObjAnimate( "spr_boxes_lvl2_cap", "pos_xy", 0, 1, func_end, { 
    0.0, 0, 0, 0,   
    0.2, 3, 2, 2,   
    0.4, 3, 0, 0, 
  });

end;
--------------------------------------------------------------------------------------------
function private.AnimUseFlashlight ()

  local func_end = function ()

    cmn.Lock( false );
    common_impl.ShowBbt( 'bbt_stairflight_use_flashlight' );
    
  end;

  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level1/sfx/aud_", 0, "", 0 );
  
  if not cmn.IsEventDone( "see_stairflight_bats" ) then
    private.see_stairflight_bats ()
  else
    func_end();
  end;

end;
--------------------------------------------------------------------------------------------
function private.AnimUseWrench ()

  common_impl.ShowBbt( 'bbt_wall_use_wrench' );

  local func_end = function ()
    cmn.Lock( false );
  end;

  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "level2/sfx/aud_xx_metal_mid", 0, "", 0 );
  
  ObjAnimate( "anm_wall_lvl2_door", "pos_xy", 0, 1, func_end, { 
    0.0, 0, 0, 0,   
    0.2, 3, 2, 2,   
    0.4, 3, 0, 0, 
  });

end;
--------------------------------------------------------------------------------------------
--*********************************************************************************************************************