-- name=ho_next_armchair
--*********************************************************************************************************************
function public.Init ()
  --------------------------------------------------------------------------------------------------
  room.Define( "next_armchair" );
  game.relations[ "ho_next_armchair" ].exitroom = "rm_backyard";
  private.room_objname = "ho_next_armchair";
  --------------------------------------------------------------------------------------------------
  
  ObjSet( "obj_next_armchair_clk_wheel", {  
                                           event_mdown = function() private.WheelClick(); end, 
                                           event_menter = function () common_impl.SetCursor( CURSOR_HAND ); end,
                                           event_mleave = function () common_impl.SetCursor( CURSOR_DEFAULT ); end  
                                         } );  
  
  private.task_name = "win_next_armchair";
  private.cover_count = 12;
  private.item_count = 5;
  
  for i = 1, private.cover_count, 1 do 

    local curCover = "spr_next_armchair_piece_"..i.."_cover";  
    ObjSet( curCover, { input = true, event_mdown = function() private.CoverClick( i ); end } );
 
  end; 
                   
  for i = 1, private.item_count, 1 do 

    local curItem = "spr_next_armchair_piece_"..i.."_item";
    ObjSet( curItem, { input = false, 
                       event_mdown = function() private.ItemClick( i ); end, 
                       event_menter = function () common_impl.SetCursor( CURSOR_HAND ); end,
                       event_mleave = function () common_impl.SetCursor( CURSOR_DEFAULT ); end  
                     } );

  end;   
                     
  ObjSet( "spr_next_armchair_cross", { input = false, 
                                       event_mdown = function() cmn.HoTaskFind( "spr_next_armchair_cross", "cross" ); end, 
                                       event_menter = function () common_impl.SetCursor( CURSOR_GET ); end,
                                       event_mleave = function () common_impl.SetCursor( CURSOR_DEFAULT ); end  
                                     } );    
                                       
  --------------------------------------------------------------------------------------------
  -- function win_next_armchair () end;
  --------------------------------------------------------------------------------------------    
  common_impl.hint[ "win_next_armchair" ] = {
    type = "win",
    room = "rm_backyard",
    zz = "ho_next_armchair",
    zz_gate = "gho_backyard_next_armchair"
  };
  local win_next_armchair_inv = function ()
  
    if ( cmn.IsEventDone( "win_next_armchair" ) ) then
    
      interface.InventoryItemAdd( "inv_cross_3_lvl4", "spr_next_armchair_win" );    
    
    end;
    
  end;
  local win_next_armchair_loc = function ()
  
    if ( cmn.IsEventDone( "win_next_armchair" ) ) then
    
      ObjDelete( "gho_backyard_next_armchair" );    
    
    end;
    
  end;

  cmn.AddSubscriber( "win_next_armchair", win_next_armchair_inv );
  cmn.AddSubscriber( "win_next_armchair", win_next_armchair_loc, "rm_backyard" );
  --------------------------------------------------------------------------------------------------
  local start_next_armchair_func = function ()

    if ( cmn.IsEventStart( "win_next_armchair" ) ) then

      local ho_found = ng_global.progress[ "ext" ][ "win_next_armchair" ].found;

      for i = 1, #ho_found, 1 do
      
        ObjDelete( ho_found[ i ][ "object" ] );
      
      end;
      
      local foundItems = ng_global.progress[ ng_global.currentprogress ][ private.task_name ].found_items;

      local winCount = 0;

      for i = 1, #foundItems, 1 do 

        if ( foundItems[ i ].is_piece_found ) then 

          winCount = winCount + 1;

          local curItemID = foundItems[ i ].id_part;
          local curPart = "spr_next_armchair_piece_"..curItemID;
          ObjSet( curPart, { alp = 1 } );

        else 

          local curItemID = foundItems[ i ].id_part;
          local curItem = "spr_next_armchair_piece_"..curItemID.."_item";
          ObjSet( curItem, { input = true } );

        end; 

      end;

      if ( winCount == private.item_count and #foundItems == private.cover_count ) then 

        ObjMultiSet( { 
          { "spr_next_armchair_cross",  { alp = 1, visible = true, input = true } },
          { "obj_next_armchair_pieces",  { alp = 0, visible = false, input = false } },
        } );

      end;     

    end;

  end;
  cmn.AddSubscriber( "win_next_armchair", start_next_armchair_func, private.room_objname ); 

end;


--*********************************************************************************************************************
function public.PreOpen ()
  
  cmn.StopMusEnv();
  common_impl.StopAllMus();
  int_slider.InitSlider( private.room_objname );

  common_impl.PlayMusEnvHO();
  cmn.PlayMusEnv( "mus_env/aud_ho_mus_env", true );
  common_impl.PlayAudio( "env", "levelext/env/aud_backyard_env", 0, "", 0 );

  if ( not cmn.IsEventDone( "opn_next_armchair" ) ) then
  
    cmn.InitHo( "next_armchair" );
    cmn.SetEventDone( "opn_next_armchair" );

    ng_global.progress[ ng_global.currentprogress ][ private.task_name ].found_items = {};
  
  end;

  local ho_items = {};

  for i = 1, private.cover_count, 1 do 
    
    local curCover = "spr_next_armchair_piece_"..i.."_cover";
    local curCoverTask = "piece_"..i.."_cover";
     
    interface.TaskPanelTaskAdd( ho_items, curCoverTask,             1, 0, { { curCover } } );

  end; 

  for i = 1, private.item_count, 1 do 

    local curItem = "spr_next_armchair_piece_"..i.."_item";
    local curItemTask = "piece_"..i.."_item";
    interface.TaskPanelTaskAdd( ho_items, curItemTask,              1, 0, { { curItem } } );

  end; 
  
  interface.TaskPanelTaskAdd( ho_items, "cross",                    1, 0, { { "spr_next_armchair_cross" } } );
  interface.TaskPanelShow( ho_items );  

  ObjAttach( "obj_int_taskpanel_next_armchair", "int_taskpanel_impl" ); 
  private.TaskPanelUpdate(); 

end;


--*********************************************************************************************************************
function public.Open ()

  common_impl.PassingHoStart();
  
end;


--*********************************************************************************************************************
function public.PreClose ()

  interface.TaskPanelHide();
  
end;


--*********************************************************************************************************************
function public.Close ()

  cmn.PlayMusEnv();
  common_impl.PassingHoStop();

  ObjSet( "obj_int_taskpanel", { alp = 1, visible = true } );
  ObjDetach( "obj_int_taskpanel_next_armchair" );

end;


--*********************************************************************************************************************
function public.HoComplete ()
  
  common_impl.PassingHoWin(); 
  
end;


--*********************************************************************************************************************
function private.CoverClick ( id )

  local curCover = "spr_next_armchair_piece_"..id.."_cover";
  local curCoverTask = "piece_"..id.."_cover";

  cmn.HoTaskFind( curCover, curCoverTask );
  
  if ( id <= private.item_count ) then 

    local curItem = "spr_next_armchair_piece_"..id.."_item";
    ObjSet( curItem, { input = true } );

  end; 

  local element = { id_part = id, is_piece_found = false }; 
  table.insert( ng_global.progress[ ng_global.currentprogress ][ private.task_name ].found_items, element ); 
  
  if ( private.CheckingOnAllItemsFound() and
  private.CheckingOnAllCoversFound() ) then 

    ObjMultiSet( { 
      { "spr_next_armchair_cross",  { alp = 1, visible = true, input = true } },
      { "obj_next_armchair_pieces",  { alp = 0, visible = false, input = false } },
    } );
    
  end; 
  
  private.TaskPanelUpdate(); 

end;


--*********************************************************************************************************************
function private.ItemClick ( id )

  local func_end = function () 

    cmn.Lock( false );

  end;

  local curItem = "spr_next_armchair_piece_"..id.."_item";
  local curItemTask = "piece_"..id.."_item";
  
  cmn.HoTaskFind( curItem, curItemTask );

  local curPiece = "spr_next_armchair_piece_"..id;

  cmn.Lock( true );
  ObjAnimate( curPiece, "alp",0,0, func_end, { 0, 0, 0,    0.3, 0, 1 } );

  private.MarkingFoundItem( id );
  
  if ( private.CheckingOnAllItemsFound() and
  private.CheckingOnAllCoversFound() ) then 

    ObjMultiSet( { 
      { "spr_next_armchair_cross",  { alp = 1, visible = true, input = true } },
      { "obj_next_armchair_pieces",  { alp = 0, visible = false, input = false } },
    } );
    
  end;
  
  private.TaskPanelUpdate();

end;


--*********************************************************************************************************************
function private.TaskPanelUpdate () 

  if private.CheckingOnAllCoversFound() then 

    ObjSet( "obj_int_taskpanel", { alp = 0, visible = false } );
    ObjSet( "txt_next_armchair_taskpanel", { alp = 1, visible = true } );

    local count = private.item_count - private.GettingFoundItemsCount();

    ObjSet( "txt_next_armchair_taskpanel",
    {
       text   = "str_next_armchair_task",
       param0 = count
    } );

    if count == 0 then 
    
      ObjSet( "txt_next_armchair_taskpanel", { text = "str_next_armchair_final" } );

    end;

  end;

end;


--*********************************************************************************************************************
function private.MarkingFoundItem ( id )

  local foundItems = ng_global.progress[ ng_global.currentprogress ][ private.task_name ].found_items;

  for i = 1, #foundItems, 1 do 

    if ( foundItems[ i ].id_part == id ) and ( not foundItems[ i ].is_piece_found ) then 

      foundItems[ i ].is_piece_found = true; 
      break; 

    end; 

  end; 

  ng_global.progress[ ng_global.currentprogress ][ private.task_name ].found_items = foundItems; 

end; 


--*********************************************************************************************************************
function private.CheckingOnAllItemsFound ()

  local foundItems = ng_global.progress[ ng_global.currentprogress ][ private.task_name ].found_items;
  local result = false; 
  local count = 0;

  for i = 1, #foundItems, 1 do 

    if ( foundItems[ i ].is_piece_found ) then 

      count = count + 1; 

    end; 

  end; 

  if private.item_count == count then 

    result = true;

  end;

  return result;

end; 


--*********************************************************************************************************************
function private.CheckingOnAllCoversFound ()

  local foundItems = ng_global.progress[ ng_global.currentprogress ][ private.task_name ].found_items;
  local result = false; 
  local count = 0;

  for i = 1, #foundItems, 1 do 

    if ( foundItems[ i ] ) then 

      count = count + 1; 

    end; 

  end; 

  if private.cover_count == count then 

    result = true;

  end;

  return result;

end; 


--*********************************************************************************************************************
function private.GettingFoundItemsCount ()

  local foundItems = ng_global.progress[ ng_global.currentprogress ][ private.task_name ].found_items;
  local count = 0;

  for i = 1, #foundItems, 1 do 

    if ( foundItems[ i ].is_piece_found ) then 

      count = count + 1; 

    end; 

  end; 

  return count;

end; 


--*********************************************************************************************************************
function private.IsCoverFound ( coverID )
  
  local foundItems = ng_global.progress[ ng_global.currentprogress ][ private.task_name ].found_items;
  local result = false; 

  for i = 1, #foundItems, 1 do 

    if ( foundItems[ i ].id_part == coverID ) then 

      result = true;
      break; 

    end; 

  end; 

  return result;
  
end;


--*********************************************************************************************************************
function private.WheelClick ()
  
  local func_end = function()

    cmn.Lock( false );
    
    if ( not private.IsCoverFound( 9 ) ) then   
      
      ObjMultiSet( { 
        { "spr_next_armchair_piece_9_cover_visible",  { alp = 0, visible = false } },
        { "spr_next_armchair_piece_9_cover",  { alp = 1, visible = true } },
      } );
      
    end;
  
  end; 
  
  if ( not private.IsCoverFound( 9 ) ) then
    
    ObjMultiSet( { 
      { "spr_next_armchair_piece_9_cover",  { alp = 0, visible = false } },
      { "spr_next_armchair_piece_9_cover_visible",  { alp = 1, visible = true } },
    } );    
    
  end;
  
  cmn.Lock( true );
  common_impl.PlayAudio( "sfx", "levelext/sfx/aud_xx_clk_rule_4lvl", 0, "", 0 );
  AnimPlay( "anm_next_armchair_wheel", "wheel", func_end );
  
end;








