-- name=rm_collectibles
--******************************************************************************************
function public.Init ()  

  private.timer_count = 0;
  private.timer_array = {};
  
  private.MUSIC_ARRAY = {
                          "aud_spider_collect_mus",
                          "aud_balls_collect_mus",
                          "aud_stemware_collect_mus",
                          "aud_lamp_collect_mus",
                          "aud_book_collect_mus",
                          "aud_tube_collect_mus", 
                          "aud_clock_collect_mus",
                          "aud_ball_collect_mus",
                          "aud_mirror_collect_mus",
                          "aud_leaf_collect_mus",
                          "aud_drop_collect_mus",
                          "aud_bees_collect_mus",
                          "aud_chimes_collect_mus" 
                        };
                        
  private.ANIM_FUNCTION_ARRAY = {
                                  "spider",
                                  "balls",
                                  "glasses",
                                  "lamp",
                                  "book",
                                  "pipes", 
                                  "clock",
                                  "ball",
                                  "mirror",
                                  "window",
                                  "drop",
                                  "flower",
                                  "wind"
                                };  
  
  
  private.MUSIC_PATH = "level1/mus/";
  private.AREA_ACTIVE_NAME = "obj_collectibles_active_area_";
  private.AREA_PASSIVE_NAME = "obj_collectibles_passive_area_";
  
  private.RECEIVED_ANIM_NAME = "anm_collectibles_received_anim_";
  private.NOT_RECEIVED_ANIM_NAME = "anm_collectibles_not_received_anim_";
  
  private.TIMER_NAME = "tmr_collectibles_main_timer";
  
  
--------------------------------------------------------------------------------------------
  local table_multiset = {};
  
  for i = 1, common_impl.collectiblesMusicCount, 1 do
    
    local curAreaActive = private.AREA_ACTIVE_NAME..i;
    local curAreaPassive = private.AREA_PASSIVE_NAME..i;
    
    table.insert( table_multiset, { curAreaActive, { 
        event_mdown = function() private.DeactivateAnim( i ); end, 
        event_menter = function() SetCursor( CURSOR_HAND ); end, 
        event_mleave = function() SetCursor( CURSOR_DEFAULT ); end 
    } } ); 
     
    table.insert( table_multiset, { curAreaPassive, { 
        event_mdown = function() private.ActivateAnim( i ); end, 
        event_menter = function() SetCursor( CURSOR_HAND ); end, 
        event_mleave = function() SetCursor( CURSOR_DEFAULT ); end 
    } } );         
        
  end;

  table.insert( table_multiset, { "obj_collectibles_btn_exit", { 
      event_mdown = private.BtnCloseMouseDown, 
      event_menter = function() private.BtnMouseEnter( CURSOR_HAND, "spr_collectibles_btn_exit_focus" ); end, 
      event_mleave = function() private.BtnMouseLeave(              "spr_collectibles_btn_exit_focus" ); end 
  } } );
        
  if ( #table_multiset > 0 ) then
    ObjMultiSet( table_multiset );
  end;

end;


--******************************************************************************************
function public.PreOpen ()
  
  for i = 1, #private.timer_array, 1 do 
    
    local curTimer = private.timer_array[ i ];
    ObjDelete( curTimer );
    
  end;
  
  private.timer_count = 0;
  private.timer_array = {};
  
  private.StartTimer();
  private.Update();
  
end;


--******************************************************************************************
function public.Open ()
  
end;


--******************************************************************************************
function public.PreClose ()
  
  private.StopTimer();
  
  for i = 1, common_impl.collectiblesMusicCount, 1 do
    
    local curMus = private.MUSIC_PATH..private.MUSIC_ARRAY[ i ];
    common_impl.StopAudio( "sfx", curMus, 0.2 );
    
  end;   
  
end;


--******************************************************************************************
function public.Close ()
  
  local current_room = common.GetCurrentRoom();
  
  if ( current_room ) then 
    
    cmn.ExitRmWithoutInterface(); 
    
  end;

end;


--******************************************************************************************
function private.BtnMouseEnter( type_cursor, obj )
      
  if ( type_cursor ) then
    SetCursor( type_cursor );
  else
    SetCursor( CURSOR_DEFAULT );
  end;
    
  local alp = ObjGet( obj ).alp;
  local time = 0.3;

  ObjAnimate( obj, "alp", 0, 0, "", 
  { 
    0.0,              0, alp, 
    time*( 1 - alp ), 0, 1
  } );

end;


--******************************************************************************************
function private.BtnMouseLeave( obj )
    
  SetCursor( CURSOR_DEFAULT );

  local alp = ObjGet( obj ).alp;
  local time = 0.3;

  ObjAnimate( obj, "alp", 0, 0, "", 
  { 
    0.0,        0, alp,
    time * alp, 0,   0 
  });

end;

--******************************************************************************************
--port.
function public.Hide()
  private.BtnCloseMouseDown();  -- public. or private.
end;
--******************************************************************************************
function private.BtnCloseMouseDown( )

  local curRoom = common.GetCurrentRoom();
  
  if ( not curRoom ) then
 
    curRoom = "rm_extra";

  end;  

  common.GotoRoom( curRoom );

end;


--******************************************************************************************
function private.DeactivateAnim( id )
  
  local curAreaActive = private.AREA_ACTIVE_NAME..id;
  local curAreaPassive = private.AREA_PASSIVE_NAME..id; 
  
  local curAnim = private.RECEIVED_ANIM_NAME..id; 
  local curMus = private.MUSIC_PATH..private.MUSIC_ARRAY[ id ];
  
  ObjMultiSet( { 
    { curAreaActive,  { input = false } },
    { curAreaPassive,  { input = true } },
  } );
  
  ObjSet( curAnim, { active = false } );
  common_impl.StopAudio( "sfx", curMus, 0.2 );
  
end;


--******************************************************************************************
function private.ActivateAnim( id )
  
  local curAreaActive = private.AREA_ACTIVE_NAME..id;
  local curAreaPassive = private.AREA_PASSIVE_NAME..id; 
  
  local curAnim = private.RECEIVED_ANIM_NAME..id; 
  local curAnimFunc = private.ANIM_FUNCTION_ARRAY[ id ];
  local curMus = private.MUSIC_PATH..private.MUSIC_ARRAY[ id ];
  
  local curTimer = "tmr_collectibles_"..id;
  local remainTime = private.GettingTime();
  
  local func_end = function()
    
    AnimPlay( curAnim, curAnimFunc, "" );
    ObjSet( curAnim, { active = true } );
    common_impl.PlayAudio( "sfx", curMus, 1 );

    ObjMultiSet( { 
      { curAreaActive,  { input = true } },
    } );
    
    private.RemoveTimerFromArray( curTimer ); 
    ObjDelete( curTimer );
  
  end;
  
  ObjCreate( curTimer, "timer" );
  ObjAttach( curTimer, "rm_collectibles" );
  
  table.insert( private.timer_array, curTimer );
  
  ObjMultiSet( { 
    { curAreaPassive,  { input = false } },
    { curTimer,  { endtrig = func_end, time = remainTime, playing = true } },
  } );  
  
end;


--*******************************************************************************************************************
function private.RemoveTimerFromArray ( timerName )
  
  for i = 1, #private.timer_array, 1 do 
    
    if ( private.timer_array[ i ] == timerName ) then
      
      table.remove( private.timer_array, i );
      break;
      
    end;
    
  end;
  
end;


--*******************************************************************************************************************
function private.GettingTime ()
  
  local lastTime = private.timer_count;
  local intPart = math.floor( lastTime );
  
  local bigPart = 0; 
  local resultTime = 0;
  
  if ( intPart % 2 == 0 ) then
    
    bigPart = intPart + 2;
    
  else
    
    bigPart = intPart + 1;
    
  end;
  
  resultTime = bigPart - lastTime;
    
  return resultTime;
  
end;


--*******************************************************************************************************************
function private.StartTimer ()
  
  local func_end = function()
    
    private.StartTimer();
    
  end;
  
  private.timer_count = private.timer_count + 0.01;
  ObjSet( private.TIMER_NAME, { endtrig = func_end, time = 0.01, playing = true } ); 
  
end;


--*******************************************************************************************************************
function private.StopTimer ()

  private.timer_count = 0;
  ObjSet( private.TIMER_NAME, { playing = false } ); 

end;


--*******************************************************************************************************************
function private.Update ()
  
  for i = 1, common_impl.collectiblesMusicCount, 1 do
    
    local curTask = ng_global.collectibles_music[ "get_collect_music_"..i ];
  
    local receiveAnim = private.RECEIVED_ANIM_NAME..i;
    local notReceiveAnim = private.NOT_RECEIVED_ANIM_NAME..i;
    local receiveAnimFunc = private.ANIM_FUNCTION_ARRAY[ i ];
    
    local areaActive = private.AREA_ACTIVE_NAME..i; 
    local areaPassive = private.AREA_PASSIVE_NAME..i; 
    
    if ( curTask.done ) then
    
      ObjMultiSet( { 
        { receiveAnim,  { alp = 1, visible = true, active = true } },
        { notReceiveAnim,  { alp = 0, visible = false } },
        { areaActive,  { input = true } },
        { areaPassive,  { input = false } } 
      } );
      
      AnimPlay( receiveAnim, receiveAnimFunc, "" );
      
      local curMus = private.MUSIC_PATH..private.MUSIC_ARRAY[ i ];
      common_impl.PlayAudio( "sfx", curMus, 1 );  
      
    else 
      
      ObjMultiSet( { 
        { receiveAnim,  { alp = 0, visible = false } },
        { notReceiveAnim,  { alp = 1, visible = true } },
        { areaActive,  { input = false } },
        { areaPassive,  { input = false } } 
      } );
      
    end; 
    
  end;
  
end;




